@@ -11,8 +11,8 @@
 #'  
 #'  \eqn{S(LC(x,t), t) = S(0, t)*(1- x/100)},
 #'  
-#'  where \eqn{S(LC(x,t), t)} is the survival rate at concentration
-#'  \eqn{LC(x,t)} at time \eqn{t}, and \eqn{S(0,t)} is the survival rate at
+#'  where \eqn{S(LC(x,t), t)} is the survival probability at concentration
+#'  \eqn{LC(x,t)} at time \eqn{t}, and \eqn{S(0,t)} is the survival probability at
 #'  no concentration (i.e. concentration is \eqn{0}) at time \eqn{t} which
 #'  reflect the background mortality \eqn{h_b}:
 #'  
@@ -33,16 +33,16 @@
 #'
 #' @return The function returns an object of class \code{LCx}, which is a list
 #'  with the following information:
-#' \item{X_prop}{Survival rate of individuals surviving considering the median
+#' \item{X_prop}{Survival probability of individuals surviving considering the median
 #'  of the background mortality (i.e. \eqn{S(0, t)*(1- x/100)})}
-#' \item{X_prop_provided}{Survival rate of individuals surviving as provided in arguments (i.e. \eqn{(100-X)/100)}}
+#' \item{X_prop_provided}{Survival probability of individuals surviving as provided in arguments (i.e. \eqn{(100-X)/100)}}
 #' \item{time_LCx}{A number giving the time at which  \eqn{LC_{x}} has to be
 #'  estimated as provided in arguments or if NULL, the latest time point of the
 #'   experiment is used.}
 #' \item{df_LCx}{A \code{data.frame} with quantiles (median, 2.5\% and 97.5\%)
 #'  of \eqn{LC_{X}} at time \code{time_LCx} for \eqn{X}\% of individuals}
 #' \item{df_dose}{A \code{data.frame} with four columns: \code{concentration}, and median \code{q50} and 95\% credible interval
-#'  (\code{qinf95} and \code{qsup95}) of the survival rate at time \code{time_LCx}}
+#'  (\code{qinf95} and \code{qsup95}) of the survival probability at time \code{time_LCx}}
 #' 
 #'    
 #' @examples 
@@ -197,7 +197,7 @@ pointsLCx <- function(df_dose, X_prop){
   } else {
     LCX_q50 = NA
     
-    warning(paste("No median for survival rate of", X_prop,
+    warning(paste("No median for survival probability of", X_prop,
                   " in the range of concentrations under consideration: [",
                   min(df_dose$concentration), ";", max(df_dose$concentration), "]"))
   }
@@ -214,7 +214,7 @@ pointsLCx <- function(df_dose, X_prop){
   } else{
     LCX_qinf95 = NA
     
-    warning(paste("No 95%inf for survival rate of", X_prop ,
+    warning(paste("No 95%inf for survival probability of", X_prop ,
                   " in the range of concentrations under consideration: [",
                   min(df_dose$concentration), ";", max(df_dose$concentration), "]"))
   }
@@ -232,7 +232,7 @@ pointsLCx <- function(df_dose, X_prop){
   } else{
     
     LCX_qsup95 = NA
-    warning(paste("No 95%sup for survival rate of", X_prop,
+    warning(paste("No 95%sup for survival probability of", X_prop,
                   " in the range of concentrations under consideration: [",
                   min(df_dose$concentration), ";", max(df_dose$concentration), "]"))
   }
