@@ -1,21 +1,24 @@
 #' Posterior predictive check plot for \code{reproFitTT} objects
 #'
 #' This is the generic \code{ppc} S3 method for the \code{reproFitTT} class.
-#' It Plots the predicted values with 95 \% credible intervals versus the observed
+#' It plots the predicted values with 95\% credible intervals versus the observed
 #' values.
 #' 
 #' The coordinates of black points are the observed values of the cumulated number
-#' of reproduction outputs for a given concentration (x-scale) and the corresponding 
-#' predicted values (y-scale). 95 \% prediction intervals are added to each predicted
+#' of reproduction outputs for a given concentration (\eqn{X}-scale) and the corresponding 
+#' predicted values (\eqn{Y}-scale). 95\% prediction intervals are added to each predicted
 #' value, colored in green if this interval contains the observed value and in red
 #' in the other case. As replicates are not pooled in this plot, overlapped points
-#' are shifted on the x-axis to help the visualization of replicates. The bisecting
+#' are shifted on the \eqn{X-}axis to help the visualization of replicates. The bisecting
 #' line (y = x) is added to the plot in order to see if each prediction interval
-#' contains each observed value. As replicates are shifted on the x-axis, this
-#' line is represented by steps.
+#' contains each observed value. As replicates are shifted on the \eqn{X}-axis, this
+#' line may be represented by steps.
 #'
 #' @param x An object of class \code{reproFitTT}
+#' @param xlab A label for the \eqn{X}-axis, by default \code{Observed Cumul. Nbr. of offspring}
+#' @param ylab A label for the \eqn{Y}-axis, by default \code{Predicted Cumul. Nbr. of offspring}
 #' @param style graphical backend, can be \code{'generic'} or \code{'ggplot'}
+#' @param main main title for the plot
 #' @param \dots Further arguments to be passed to generic methods
 #'
 #' @examples
@@ -24,11 +27,11 @@
 #' data(cadmium1)
 #'
 #' # (2) Create an object of class "reproData"
-#' dat <- reproData(cadmium1)
+#' dataset <- reproData(cadmium1)
 #'
 #' \dontrun{
-#' # (3) Run the reproFitTT function with the log-logistic gamma-poisson model
-#' out <- reproFitTT(dat, stoc.part = "gammapoisson",
+#' # (3) Run the reproFitTT function with the log-logistic gamma-Poisson model
+#' out <- reproFitTT(dataset, stoc.part = "gammapoisson",
 #' ecx = c(5, 10, 15, 20, 30, 50, 80), quiet = TRUE)
 #'
 #' # (4) Plot observed versus predicted values
@@ -40,14 +43,15 @@
 #' @importFrom graphics plot
 #'
 #' @export
-ppc.reproFitTT <- function(x, style = "generic", ...) {
+ppc.reproFitTT <- function(x,
+                           style = "ggplot", 
+                           xlab = "Observed Cumul. Nbr. of offspring",
+                           ylab = "Predicted Cumul. Nbr. of offspring",
+                           main = NULL, ...) {
   if (!is(x, "reproFitTT"))
     stop("x is not of class 'reproFitTT'!")
-  
-  xlab <- "Observed Cumul. Nbr. of offspring"
-  ylab <- "Predicted Cumul. Nbr. of offspring"
 
-  ppc_gen(EvalreproPpc(x), style, xlab, ylab)
+  ppc_gen(EvalreproPpc(x), style, xlab, ylab, main)
 }
 
 
